@@ -82,6 +82,8 @@ few special cases:
     PyScons(targets, sources, "my_scons.py", clean = True) # intermediate file deleted
     PyScons(targets, sources, "my_scons.py", clean = False) # intermediate file retained
 
+4. PyScons ignores the "options" parameter when constructing the command's signature, enabling you to change parameters (e.g. the -j number of procs) without triggering a rebuild.
+
 Unfortunately, dependency tracking does not propagate up from the spawned scons. In this example, 
 "step1.py" and "step2.py" will not be tracked and changes to them will not trigger a rebuild. There
 is a trick around this, add the following two lines to "my_scons.py"
@@ -130,6 +132,7 @@ S. Joshua Swamidass (homepage_)
 """
 import os
 from SCons import Util
+from SCons.Action import CommandGeneratorAction
 from SCons.Scanner import Scanner
 from SCons.Script.SConscript import DefaultEnvironmentCall
 from modulefinder import ModuleFinder as MF
@@ -214,27 +217,28 @@ def _PyScons(env, target, source, scons, options="-Q", clean = True, tempdir = N
     args = " ".join(["in%g=%s" % (n+1, str(s)) for n,s in enumerate(source)])
     args += " " + " ".join(["out%g=%s" % (n+1, str(s)) for n,s in enumerate(target)])
 
-
-    cmd = "scons %s -f%s %s --clean" % (options, scons, args)
+    sig = "scons -f%s %s" % (scons, args)
     if tempdir == None:
         m = hashlib.sha1()
-        m.update(cmd)
+        m.update(sig)
         TEMP = os.path.join("temp", base64.b64encode(m.digest(), "+="), '')
     else: TEMP = tempdir
 
     args += " " + "temp=" + TEMP    
-
+    cmd = "scons %s -f%s %s" % (options, scons, args)
+    clean = cmd + " --clean"
+    
     if env.GetOption("clean") and not clean: 
-        env.Execute("scons %s -f%s %s --clean" % (options, scons, args))
+        env.Execute(clean)
         env.Execute(Delete(TEMP))
 
-    cmd = "scons %s -f${SOURCES[-1]} %s" % (options, args)
     if clean: 
-        cmd = [Mkdir(TEMP), cmd, "scons %s -f${SOURCES[-1]} %s --clean" % (options, args), Delete(TEMP)]
+        cmd = [Mkdir(TEMP), cmd, clean, Delete(TEMP)]
     else:
         cmd = [Mkdir(TEMP), cmd]
 
-    return env.Command(target, source + [scons], cmd)
+    gen = lambda source, target, env, for_signature: sig if for_signature else cmd 
+    return env.Command(target, source + [scons], CommandGeneratorAction(gen,{}))
 
 PyScons = DefaultEnvironmentCall("PyScons")
 PyScript = DefaultEnvironmentCall("PyScript")
